<?php

require_once WICKED_BASE . '/lib/Page/StandardPage.php';

/**
 * Wicked PageSearch class.
 *
 * $Horde: wicked/lib/Page/PageSearch.php,v 1.1 2004/08/01 00:55:58 eraserhd Exp $
 *
 * @author  Jason M. Felice <jfelice@cronosys.com>
 * @version $Revision: 1.1 $
 * @package Wicked
 */
class PageSearch extends Page {

    /**
     * Display modes supported by this page.
     */
    var $supportedModes = array(
        WICKED_MODE_CONTENT => true,
        WICKED_MODE_DISPLAY => true);

    /**
     * Render this page in Content mode.
     *
     * @param string $searchtext  The title to search for.
     *
     * @return string  The page content, or PEAR_Error.
     */
    function content($searchtext = '')
    {
        global $wicked;

        if (empty($searchtext)) {
            return array();
        }

        return $wicked->searchText($searchtext);
    }

    /**
     * Render this page in Display mode.
     *
     * @param string $searchtext  The title to search for.
     *
     * @return mixed  Returns true or PEAR_Error.
     */
    function display($searchtext = '')
    {
        $summaries = $this->content($searchtext);
        if (is_a($summaries, 'PEAR_Error')) {
            global $notification;
            $notification->push('Error retrieving summaries : ' .
                                $summaries->toString(), 'horde.error');
            return $summaries;
        }

        require_once 'Horde/Template.php';
        $template = &new Horde_Template();
        $pages = array();
        foreach ($summaries as $page) {
            if (!empty($page['page_history'])){
                $page = &new StdHistoryPage($page);
            } else {
                $page = &new StandardPage($page);
            }

            $pages[] = array('author' => $page->author(),
                             'created' => $page->formatVersionCreated(),
                             'name' => $page->pageName(),
                             'url' => $page->pageUrl(),
                             'version' => $page->version());
        }
        $template->set('pages', $pages);

        // Show search form and page header.
        require WICKED_TEMPLATES . '/pagelist/pagesearch.inc';
        echo $template->fetch(WICKED_TEMPLATES . '/pagelist/pagelist.html');
        require WICKED_TEMPLATES . '/pagelist/footer.inc';
        return true;
    }

    function pageName()
    {
        return _("PageSearch");
    }

    function pageUrl($linkpage = 'display.php', $actionid = null)
    {
        $url = Horde::applicationUrl($linkpage);
        return Util::addParameter($url, 'page', 'PageSearch');
    }

}
