<?php
// Modes we might be displaying a page in.
/** Display mode. */
define('WICKED_MODE_DISPLAY', 0);

/** The edit screen. */
define('WICKED_MODE_EDIT', 1);

/** Page can be removed. */
define('WICKED_MODE_REMOVE', 2);

/** Display the page history. */
define('WICKED_MODE_HISTORY', 3);

/** Diff two versions of the page. */
define('WICKED_MODE_DIFF', 4);

/** Info about the page. */
define('WICKED_MODE_INFO', 5);

/** Show debug info. */
define('WICKED_MODE_DEBUG', 6);

/** Page can be locked. */
define('WICKED_MODE_LOCKING', 7);

/** The ability to add a page. */
define('WICKED_MODE_CREATE', 8);

/** Raw content mode. */
define('WICKED_MODE_CONTENT', 9);

/** Like display, but for a block. */
define('WICKED_MODE_BLOCK', 10);

/** Our wiki word regexp (needed many places). */
define('WICKED_REGEXP_WIKIWORD', "[A-Z]" .         // 1 upper
                                 "[A-Za-z0-9]*" .  // 0+ alpha or digit
                                 "[a-z0-9]+" .     // 1+ lower or digit
                                 "[A-Z]" .         // 1 upper
                                 "[A-Za-z0-9]*");  // 0+ or more alpha or digit


/** Where we store our attachments in VFS. */
define('WICKED_VFS_ATTACH_PATH', '.horde/wicked/attachments');

/**
 * Wicked Base Class.
 *
 * $Horde: wicked/lib/Wicked.php,v 1.20 2004/11/21 22:23:29 chuck Exp $
 *
 * @author  Tyler Colbert <tyler-hordeml@colberts.us>
 * @version $Revision: 1.20 $
 * @package Wicked
 */
class Wicked {

    /**
     * Build Wicked's list of menu items.
     *
     * @access public
     */
    function getMenu($returnType = 'object')
    {
        global $conf, $page;

        require_once 'Horde/Menu.php';

        $menu = &new Menu(HORDE_MENU_MASK_ALL);

        if (@count($conf['menu']['pages'])) {
            foreach ($conf['menu']['pages'] as $pagename) {
                /* Determine who we should say referred us. */
                $curpage = isset($page) ? $page->pageName() : null;
                $referrer = Util::getFormData('referrer', $curpage);

                /* Determine if we should depress the button. We have to do
                 * this on our own because all the buttons go to the same .php
                 * file, just with different args. */
                if (!strstr($_SERVER['PHP_SELF'], 'prefs.php') &&
                    $curpage === _($pagename)) {
                    $cellclass = 'current';
                } else {
                    $cellclass = '__noselection';
                }

                /* Construct the URL. */
                $url = Horde::applicationUrl('display.php');
                $url = Util::addParameter($url, array('page' => $pagename,
                                                      'referrer' => $referrer));

                $menu->add($url, _($pagename), $pagename . '.png', null, null, null, $cellclass);
            }
        }

        if ($returnType == 'object') {
            return $menu;
        } else {
            return $menu->render();
        }
    }

    /**
     * Mails a notification message.
     *
     * @param string $message  The message text to send out.
     * @param array $headers   Additional headers to add to the email.
     *
     * @return mixed  The result of the send mail call.
     */
    function mail($message, $headers = array())
    {
        global $conf, $registry;

        // Make sure there's a place configured to send the email.
        if (empty($conf['wicked']['notify_address'])) {
            return;
        }

        // In case we don't get a user's email address to send the
        // notification from, what should we fall back to for the
        // From: header?
        $default_from_addr = !empty($conf['wicked']['guest_address']) ?
            $conf['wicked']['guest_address'] :
            $conf['wicked']['notify_address'];

        require_once 'Mail.php';
        require_once 'Horde/MIME.php';

        if (Auth::getAuth()) {
            require_once 'Horde/Identity.php';
            $identity = &Identity::singleton();
            $from = $identity->getValue('fullname');
            if (empty($from)) {
                $from = $registry->get('name');
            }
            $from_addr = $identity->getValue('from_addr');
            if (empty($from_addr)) {
                $from_addr = $default_from_addr;
            }
        } else {
            $from = $registry->get('name') . ' Guest';
            $from_addr = $default_from_addr;
        }

        $headers['From'] = MIME::encodeAddress($from . '<' . $from_addr . '>');
        $headers['To'] = MIME::encodeAddress($conf['wicked']['notify_address'], null, $conf['server']['name']);

        $mailer = &Mail::factory($conf['mailer']['type'], $conf['mailer']['params']);
        return $mailer->send($headers['To'], $headers, $message);
    }

}
